==> lumina-1.1.0.tar.gz: lumina-1.1.0/src-qt5/core/lumina-open/i18n/lumina-open_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>LFileDialog</name>
    <message>
        <location filename="../LFileDialog.ui" line="14"/>
        <source>Open With...</source>
        <translation>Ouvir avec...</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="68"/>
        <source>Preferred</source>
        <translation>Favori</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="75"/>
        <source>Available</source>
        <translation>Disponible</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="82"/>
        <source>Custom</source>
        <translation>Personnalisé</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="131"/>
        <source>Binary Location</source>
        <translation>Emplacement du binaire :</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="138"/>
        <source>Find</source>
        <translation>Trouver</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="199"/>
        <source>Set this application as the default </source>
        <translation>Mettre cette application par défaut</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="221"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="235"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="40"/>
        <source>(Email Link)</source>
        <translation>(Lien e-mail)</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="41"/>
        <source>(Internet URL - %1)</source>
        <translation>(URL Internet - %1)</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="114"/>
        <source>Audio</source>
        <translation>Son</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="115"/>
        <source>Video</source>
        <translation>Vidéo</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="116"/>
        <source>Multimedia</source>
        <translation>Multimédia</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="117"/>
        <source>Development</source>
        <translation>Développement</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="118"/>
        <source>Education</source>
        <translation>Éducation</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="119"/>
        <source>Game</source>
        <translation>Jeu</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="120"/>
        <source>Graphics</source>
        <translation>Graphiques</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="121"/>
        <source>Network</source>
        <translation>Réseau</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="122"/>
        <source>Office</source>
        <translation>Bureau</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="123"/>
        <source>Science</source>
        <translation>Science</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="124"/>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="125"/>
        <source>System</source>
        <translation>Système</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="126"/>
        <source>Utilities</source>
        <translation>Utilitaires</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="127"/>
        <source>Other</source>
        <translation>Autre</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="274"/>
        <source>Find Application Binary</source>
        <translation>Rechcher les Applications binaires</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>File Error</source>
        <translation>Erreur de fichier</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="188"/>
        <location filename="../main.cpp" line="194"/>
        <source>Audio Volume %1%</source>
        <translation>Volume audio %1%</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="202"/>
        <location filename="../main.cpp" line="211"/>
        <source>Screen Brightness %1%</source>
        <translation>Luminosité de l&apos;écran %1%</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="243"/>
        <source>Invalid file or URL: %1</source>
        <translation>Fichier ou URL Invalide: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="264"/>
        <source>File could not be opened: %1</source>
        <translation>Impossible d&apos;ouvrir le fichier: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="273"/>
        <source>Application shortcut is missing the launching information (malformed shortcut): %1</source>
        <translation>Information de lancement manquant (raccourci malformé): %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="284"/>
        <source>URL shortcut is missing the URL: %1</source>
        <translation>Le raccourci URL est introuvable dans l&apos;URL : %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="295"/>
        <source>Directory shortcut is missing the path to the directory: %1</source>
        <translation>Chemin vers le répertoire manquant dans le raccourci du répertoire: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="300"/>
        <source>Unknown type of shortcut : %1</source>
        <translation>Type du raccourci inconnu: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="362"/>
        <source>Binary Missing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="362"/>
        <source>Could not find &quot;%1&quot;. Please ensure it is installed first.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="412"/>
        <source>Application Error</source>
        <translation>Erreur de l&apos;application</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="412"/>
        <source>The following application experienced an error and needed to close:</source>
        <translation>L&apos;application suivante a rencontré une erreur et doit être fermée:</translation>
    </message>
</context>
</TS>

==> lumina-1.2.0.tar.gz: lumina-1.2.0/src-qt5/core/lumina-open/i18n/lumina-open_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>LFileDialog</name>
    <message>
        <location filename="../LFileDialog.ui" line="14"/>
        <source>Open With...</source>
        <translation>Ouvir avec...</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="68"/>
        <source>Preferred</source>
        <translation>Favori</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="75"/>
        <source>Available</source>
        <translation>Disponible</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="82"/>
        <source>Custom</source>
        <translation>Personnalisé</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="131"/>
        <source>Binary Location</source>
        <translation>Emplacement de l&apos;Exécutable</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="138"/>
        <source>Find</source>
        <translation>Trouver</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="199"/>
        <source>Set this application as the default </source>
        <translation>Définier ce programme par défaut </translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="221"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../LFileDialog.ui" line="235"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="40"/>
        <source>(Email Link)</source>
        <translation>(Lien e-mail)</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="41"/>
        <source>(Internet URL - %1)</source>
        <translation>(URL Internet - %1)</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="114"/>
        <source>Audio</source>
        <translation>Son</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="115"/>
        <source>Video</source>
        <translation>Vidéo</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="116"/>
        <source>Multimedia</source>
        <translation>Multimédia</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="117"/>
        <source>Development</source>
        <translation>Développement</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="118"/>
        <source>Education</source>
        <translation>Éducation</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="119"/>
        <source>Game</source>
        <translation>Jeu</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="120"/>
        <source>Graphics</source>
        <translation>Graphiques</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="121"/>
        <source>Network</source>
        <translation>Réseau</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="122"/>
        <source>Office</source>
        <translation>Bureau</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="123"/>
        <source>Science</source>
        <translation>Science</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="124"/>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="125"/>
        <source>System</source>
        <translation>Système</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="126"/>
        <source>Utilities</source>
        <translation>Utilitaires</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="127"/>
        <source>Other</source>
        <translation>Autre</translation>
    </message>
    <message>
        <location filename="../LFileDialog.cpp" line="274"/>
        <source>Find Application Binary</source>
        <translation>Rechercher le Programme Exécutable</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>File Error</source>
        <translation>Erreur de fichier</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="188"/>
        <location filename="../main.cpp" line="194"/>
        <source>Audio Volume %1%</source>
        <translation>Volume Audio %1%</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="202"/>
        <location filename="../main.cpp" line="211"/>
        <source>Screen Brightness %1%</source>
        <translation>Luminosité de l&apos;Écran %1%</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="243"/>
        <source>Invalid file or URL: %1</source>
        <translation>Fichier ou URL invalide : %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="264"/>
        <source>Application entry is invalid: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="273"/>
        <source>Application shortcut is missing the launching information (malformed shortcut): %1</source>
        <translation>Informations de lancement manquantes dans le raccourci du programme (raccourci invalide) : %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="284"/>
        <source>URL shortcut is missing the URL: %1</source>
        <translation>L&apos;adresse est introuvable dans le raccourci URL : %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="295"/>
        <source>Directory shortcut is missing the path to the directory: %1</source>
        <translation>Le chemin du dossier est vide dans le raccourci du dossier : %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="300"/>
        <source>Unknown type of shortcut : %1</source>
        <translation>Type du raccourci inconnu : %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="363"/>
        <source>Binary Missing</source>
        <translation>Exécutable Manquant</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="363"/>
        <source>Could not find &quot;%1&quot;. Please ensure it is installed first.</source>
        <translation>&quot;%1&quot; non trouvé. Vérifiez qu&apos;il soit bien installé.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="413"/>
        <source>Application Error</source>
        <translation>Erreur du Programme</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="413"/>
        <source>The following application experienced an error and needed to close:</source>
        <translation>Le programme suivant a provoqué une erreur et a dû être fermé :</translation>
    </message>
</context>
</TS>
